from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Media
import win32more.Microsoft.UI.Xaml.Media.Imaging
import win32more.Windows.ApplicationModel.Background
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Storage.Streams
class BitmapCreateOptions(Enum, UInt32):
    _name_ = 'Microsoft.UI.Xaml.Media.Imaging.BitmapCreateOptions'
    None_ = 0
    IgnoreImageCache = 8
class _BitmapImage_Meta_(ComPtr.__class__):
    pass
class BitmapImage(ComPtr, metaclass=_BitmapImage_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.BitmapImage'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapImage.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapImage.CreateInstanceWithUriSource(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapImage: ...
    @winrt_factorymethod
    def CreateInstanceWithUriSource(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageFactory, uriSource: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapImage: ...
    @winrt_mixinmethod
    def get_CreateOptions(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapCreateOptions: ...
    @winrt_mixinmethod
    def put_CreateOptions(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapCreateOptions) -> Void: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_DecodePixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Int32: ...
    @winrt_mixinmethod
    def put_DecodePixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_DecodePixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Int32: ...
    @winrt_mixinmethod
    def put_DecodePixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_DecodePixelType(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> win32more.Microsoft.UI.Xaml.Media.Imaging.DecodePixelType: ...
    @winrt_mixinmethod
    def put_DecodePixelType(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: win32more.Microsoft.UI.Xaml.Media.Imaging.DecodePixelType) -> Void: ...
    @winrt_mixinmethod
    def get_IsAnimatedBitmap(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsPlaying(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Boolean: ...
    @winrt_mixinmethod
    def get_AutoPlay(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoPlay(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_DownloadProgress(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, handler: win32more.Microsoft.UI.Xaml.Media.Imaging.DownloadProgressEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DownloadProgress(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ImageOpened(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageOpened(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ImageFailed(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, handler: win32more.Microsoft.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageFailed(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Play(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImage) -> Void: ...
    @winrt_classmethod
    def get_CreateOptionsProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DecodePixelWidthProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DecodePixelHeightProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DecodePixelTypeProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAnimatedBitmapProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlayingProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoPlayProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    CreateOptions = property(get_CreateOptions, put_CreateOptions)
    DecodePixelHeight = property(get_DecodePixelHeight, put_DecodePixelHeight)
    DecodePixelType = property(get_DecodePixelType, put_DecodePixelType)
    DecodePixelWidth = property(get_DecodePixelWidth, put_DecodePixelWidth)
    IsAnimatedBitmap = property(get_IsAnimatedBitmap, None)
    IsPlaying = property(get_IsPlaying, None)
    UriSource = property(get_UriSource, put_UriSource)
    _BitmapImage_Meta_.AutoPlayProperty = property(get_AutoPlayProperty, None)
    _BitmapImage_Meta_.CreateOptionsProperty = property(get_CreateOptionsProperty, None)
    _BitmapImage_Meta_.DecodePixelHeightProperty = property(get_DecodePixelHeightProperty, None)
    _BitmapImage_Meta_.DecodePixelTypeProperty = property(get_DecodePixelTypeProperty, None)
    _BitmapImage_Meta_.DecodePixelWidthProperty = property(get_DecodePixelWidthProperty, None)
    _BitmapImage_Meta_.IsAnimatedBitmapProperty = property(get_IsAnimatedBitmapProperty, None)
    _BitmapImage_Meta_.IsPlayingProperty = property(get_IsPlayingProperty, None)
    _BitmapImage_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
    DownloadProgress = event(add_DownloadProgress, remove_DownloadProgress)
    ImageFailed = event(add_ImageFailed, remove_ImageFailed)
    ImageOpened = event(add_ImageOpened, remove_ImageOpened)
class _BitmapSource_Meta_(ComPtr.__class__):
    pass
class BitmapSource(ComPtr, metaclass=_BitmapSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.ImageSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSource
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.BitmapSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapSource: ...
    @winrt_mixinmethod
    def get_PixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSource) -> Int32: ...
    @winrt_mixinmethod
    def get_PixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSource) -> Int32: ...
    @winrt_mixinmethod
    def SetSource(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSource, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def SetSourceAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSource, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def get_PixelWidthProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PixelHeightProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IBitmapSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
    _BitmapSource_Meta_.PixelHeightProperty = property(get_PixelHeightProperty, None)
    _BitmapSource_Meta_.PixelWidthProperty = property(get_PixelWidthProperty, None)
class DecodePixelType(Enum, Int32):
    _name_ = 'Microsoft.UI.Xaml.Media.Imaging.DecodePixelType'
    Physical = 0
    Logical = 1
class DownloadProgressEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IDownloadProgressEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.DownloadProgressEventArgs'
    @winrt_mixinmethod
    def get_Progress(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IDownloadProgressEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def put_Progress(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IDownloadProgressEventArgs, value: Int32) -> Void: ...
    Progress = property(get_Progress, put_Progress)
class DownloadProgressEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{9a8e4af5-b124-5205-8ae9-3496e063c569}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Media.Imaging.DownloadProgressEventArgs) -> Void: ...
class IBitmapImage(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapImage'
    _iid_ = Guid('{5cc29916-a411-5bc2-a3c5-a00d99a59da8}')
    @winrt_commethod(6)
    def get_CreateOptions(self) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapCreateOptions: ...
    @winrt_commethod(7)
    def put_CreateOptions(self, value: win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapCreateOptions) -> Void: ...
    @winrt_commethod(8)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(9)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(10)
    def get_DecodePixelWidth(self) -> Int32: ...
    @winrt_commethod(11)
    def put_DecodePixelWidth(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_DecodePixelHeight(self) -> Int32: ...
    @winrt_commethod(13)
    def put_DecodePixelHeight(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_DecodePixelType(self) -> win32more.Microsoft.UI.Xaml.Media.Imaging.DecodePixelType: ...
    @winrt_commethod(15)
    def put_DecodePixelType(self, value: win32more.Microsoft.UI.Xaml.Media.Imaging.DecodePixelType) -> Void: ...
    @winrt_commethod(16)
    def get_IsAnimatedBitmap(self) -> Boolean: ...
    @winrt_commethod(17)
    def get_IsPlaying(self) -> Boolean: ...
    @winrt_commethod(18)
    def get_AutoPlay(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_AutoPlay(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def add_DownloadProgress(self, handler: win32more.Microsoft.UI.Xaml.Media.Imaging.DownloadProgressEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_DownloadProgress(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_ImageOpened(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_ImageOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_ImageFailed(self, handler: win32more.Microsoft.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_ImageFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def Play(self) -> Void: ...
    @winrt_commethod(27)
    def Stop(self) -> Void: ...
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    CreateOptions = property(get_CreateOptions, put_CreateOptions)
    DecodePixelHeight = property(get_DecodePixelHeight, put_DecodePixelHeight)
    DecodePixelType = property(get_DecodePixelType, put_DecodePixelType)
    DecodePixelWidth = property(get_DecodePixelWidth, put_DecodePixelWidth)
    IsAnimatedBitmap = property(get_IsAnimatedBitmap, None)
    IsPlaying = property(get_IsPlaying, None)
    UriSource = property(get_UriSource, put_UriSource)
    DownloadProgress = event(add_DownloadProgress, remove_DownloadProgress)
    ImageFailed = event(add_ImageFailed, remove_ImageFailed)
    ImageOpened = event(add_ImageOpened, remove_ImageOpened)
class IBitmapImageFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapImageFactory'
    _iid_ = Guid('{f037e0e9-f229-522e-95c9-da2211a14b05}')
    @winrt_commethod(6)
    def CreateInstanceWithUriSource(self, uriSource: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapImage: ...
class IBitmapImageStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapImageStatics'
    _iid_ = Guid('{4bcf71a9-1897-51dc-8e3f-2c5c796d1cd9}')
    @winrt_commethod(6)
    def get_CreateOptionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_UriSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DecodePixelWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DecodePixelHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_DecodePixelTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsAnimatedBitmapProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsPlayingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_AutoPlayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AutoPlayProperty = property(get_AutoPlayProperty, None)
    CreateOptionsProperty = property(get_CreateOptionsProperty, None)
    DecodePixelHeightProperty = property(get_DecodePixelHeightProperty, None)
    DecodePixelTypeProperty = property(get_DecodePixelTypeProperty, None)
    DecodePixelWidthProperty = property(get_DecodePixelWidthProperty, None)
    IsAnimatedBitmapProperty = property(get_IsAnimatedBitmapProperty, None)
    IsPlayingProperty = property(get_IsPlayingProperty, None)
    UriSourceProperty = property(get_UriSourceProperty, None)
class IBitmapSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapSource'
    _iid_ = Guid('{8424269d-9b82-534f-8fea-af5b5ef96bf2}')
    @winrt_commethod(6)
    def get_PixelWidth(self) -> Int32: ...
    @winrt_commethod(7)
    def get_PixelHeight(self) -> Int32: ...
    @winrt_commethod(8)
    def SetSource(self, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(9)
    def SetSourceAsync(self, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class IBitmapSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapSourceFactory'
    _iid_ = Guid('{0392f025-1868-5876-ad67-12e94a8da5bf}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapSource: ...
class IBitmapSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IBitmapSourceStatics'
    _iid_ = Guid('{efa3745e-4400-5f0b-bdc7-3f2911a3d719}')
    @winrt_commethod(6)
    def get_PixelWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PixelHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PixelHeightProperty = property(get_PixelHeightProperty, None)
    PixelWidthProperty = property(get_PixelWidthProperty, None)
class IDownloadProgressEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IDownloadProgressEventArgs'
    _iid_ = Guid('{9a0ea80b-1a17-50d5-83f3-377738212619}')
    @winrt_commethod(6)
    def get_Progress(self) -> Int32: ...
    @winrt_commethod(7)
    def put_Progress(self, value: Int32) -> Void: ...
    Progress = property(get_Progress, put_Progress)
class IRenderTargetBitmap(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap'
    _iid_ = Guid('{cf10407d-fa8b-57a3-9574-710529ae0b04}')
    @winrt_commethod(6)
    def get_PixelWidth(self) -> Int32: ...
    @winrt_commethod(7)
    def get_PixelHeight(self) -> Int32: ...
    @winrt_commethod(8)
    def RenderAsync(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def RenderToSizeAsync(self, element: win32more.Microsoft.UI.Xaml.UIElement, scaledWidth: Int32, scaledHeight: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(10)
    def GetPixelsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IBuffer]: ...
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class IRenderTargetBitmapStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmapStatics'
    _iid_ = Guid('{83e822e4-9f84-5986-93b0-e4f7019c367d}')
    @winrt_commethod(6)
    def get_PixelWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PixelHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PixelHeightProperty = property(get_PixelHeightProperty, None)
    PixelWidthProperty = property(get_PixelWidthProperty, None)
class ISoftwareBitmapSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISoftwareBitmapSource'
    _iid_ = Guid('{a6aca802-1f24-5a1e-bf08-781a85ed5511}')
    @winrt_commethod(6)
    def SetBitmapAsync(self, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
class ISurfaceImageSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISurfaceImageSource'
    _iid_ = Guid('{ac078d9c-d0e0-5ff9-b73e-98e82e4c8d36}')
class ISurfaceImageSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISurfaceImageSourceFactory'
    _iid_ = Guid('{09a26ed2-11b3-5ef1-ac56-20d064ccca34}')
    @winrt_commethod(6)
    def CreateInstanceWithDimensions(self, pixelWidth: Int32, pixelHeight: Int32, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource: ...
    @winrt_commethod(7)
    def CreateInstanceWithDimensionsAndOpacity(self, pixelWidth: Int32, pixelHeight: Int32, isOpaque: Boolean, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource: ...
class ISvgImageSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource'
    _iid_ = Guid('{d5b61d3c-b68d-53a2-b07b-ba6adfdd5887}')
    @winrt_commethod(6)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_RasterizePixelWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_RasterizePixelWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_RasterizePixelHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_RasterizePixelHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def add_Opened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource, win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_OpenFailed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource, win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceFailedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_OpenFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def SetSourceAsync(self, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceLoadStatus]: ...
    RasterizePixelHeight = property(get_RasterizePixelHeight, put_RasterizePixelHeight)
    RasterizePixelWidth = property(get_RasterizePixelWidth, put_RasterizePixelWidth)
    UriSource = property(get_UriSource, put_UriSource)
    OpenFailed = event(add_OpenFailed, remove_OpenFailed)
    Opened = event(add_Opened, remove_Opened)
class ISvgImageSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFactory'
    _iid_ = Guid('{2f85673f-ac64-570d-9bda-94fa082eead9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource: ...
    @winrt_commethod(7)
    def CreateInstanceWithUriSource(self, uriSource: win32more.Windows.Foundation.Uri, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource: ...
class ISvgImageSourceFailedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFailedEventArgs'
    _iid_ = Guid('{76e66278-7804-5439-a50d-14c5ba896714}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceLoadStatus: ...
    Status = property(get_Status, None)
class ISvgImageSourceOpenedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceOpenedEventArgs'
    _iid_ = Guid('{1c9860d5-38d0-5b21-8d48-072f1e254e39}')
class ISvgImageSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceStatics'
    _iid_ = Guid('{e3ad1068-f4c6-5513-a777-2980f0ba41bd}')
    @winrt_commethod(6)
    def get_UriSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_RasterizePixelWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_RasterizePixelHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RasterizePixelHeightProperty = property(get_RasterizePixelHeightProperty, None)
    RasterizePixelWidthProperty = property(get_RasterizePixelWidthProperty, None)
    UriSourceProperty = property(get_UriSourceProperty, None)
class IVirtualSurfaceImageSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IVirtualSurfaceImageSource'
    _iid_ = Guid('{e4ff96a6-fede-589c-a007-4178b53b6739}')
class IVirtualSurfaceImageSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IVirtualSurfaceImageSourceFactory'
    _iid_ = Guid('{08490f2c-04a8-5031-b9c7-707060d7cd48}')
    @winrt_commethod(6)
    def CreateInstanceWithDimensions(self, pixelWidth: Int32, pixelHeight: Int32) -> win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource: ...
    @winrt_commethod(7)
    def CreateInstanceWithDimensionsAndOpacity(self, pixelWidth: Int32, pixelHeight: Int32, isOpaque: Boolean) -> win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource: ...
class IWriteableBitmap(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmap'
    _iid_ = Guid('{78c824a9-0e43-5f1e-93bc-d046cca82b7e}')
    @winrt_commethod(6)
    def get_PixelBuffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(7)
    def Invalidate(self) -> Void: ...
    PixelBuffer = property(get_PixelBuffer, None)
class IWriteableBitmapFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmapFactory'
    _iid_ = Guid('{26e861d9-b080-512b-96c4-80050e7e08d1}')
    @winrt_commethod(6)
    def CreateInstanceWithDimensions(self, pixelWidth: Int32, pixelHeight: Int32) -> win32more.Microsoft.UI.Xaml.Media.Imaging.WriteableBitmap: ...
class IXamlRenderingBackgroundTask(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTask'
    _iid_ = Guid('{7807000c-a050-5121-ac74-3322d5358e39}')
class IXamlRenderingBackgroundTaskFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTaskFactory'
    _iid_ = Guid('{205247a3-9ffe-599a-a21a-7181442a9d75}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.XamlRenderingBackgroundTask: ...
class IXamlRenderingBackgroundTaskOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTaskOverrides'
    _iid_ = Guid('{18733237-324b-57c0-89b2-5875472acc80}')
    @winrt_commethod(6)
    def OnRun(self, taskInstance: win32more.Windows.ApplicationModel.Background.IBackgroundTaskInstance) -> Void: ...
class _RenderTargetBitmap_Meta_(ComPtr.__class__):
    pass
class RenderTargetBitmap(ComPtr, metaclass=_RenderTargetBitmap_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.ImageSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.RenderTargetBitmap'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.RenderTargetBitmap.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Media.Imaging.RenderTargetBitmap: ...
    @winrt_mixinmethod
    def get_PixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap) -> Int32: ...
    @winrt_mixinmethod
    def get_PixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap) -> Int32: ...
    @winrt_mixinmethod
    def RenderAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def RenderToSizeAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap, element: win32more.Microsoft.UI.Xaml.UIElement, scaledWidth: Int32, scaledHeight: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetPixelsAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IBuffer]: ...
    @winrt_classmethod
    def get_PixelWidthProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmapStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PixelHeightProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IRenderTargetBitmapStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
    _RenderTargetBitmap_Meta_.PixelHeightProperty = property(get_PixelHeightProperty, None)
    _RenderTargetBitmap_Meta_.PixelWidthProperty = property(get_PixelWidthProperty, None)
class SoftwareBitmapSource(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Media.ImageSource
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.ISoftwareBitmapSource
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.SoftwareBitmapSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.SoftwareBitmapSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SoftwareBitmapSource: ...
    @winrt_mixinmethod
    def SetBitmapAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISoftwareBitmapSource, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class SurfaceImageSource(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Media.ImageSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.ISurfaceImageSource
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource.CreateInstanceWithDimensions(*args, None, None))
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource.CreateInstanceWithDimensionsAndOpacity(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithDimensions(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISurfaceImageSourceFactory, pixelWidth: Int32, pixelHeight: Int32, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource: ...
    @winrt_factorymethod
    def CreateInstanceWithDimensionsAndOpacity(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISurfaceImageSourceFactory, pixelWidth: Int32, pixelHeight: Int32, isOpaque: Boolean, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource: ...
class _SvgImageSource_Meta_(ComPtr.__class__):
    pass
class SvgImageSource(ComPtr, metaclass=_SvgImageSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Media.ImageSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.SvgImageSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource.CreateInstance(*args, None, None))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource.CreateInstanceWithUriSource(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource: ...
    @winrt_factorymethod
    def CreateInstanceWithUriSource(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFactory, uriSource: win32more.Windows.Foundation.Uri, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_RasterizePixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource) -> Double: ...
    @winrt_mixinmethod
    def put_RasterizePixelWidth(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_RasterizePixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource) -> Double: ...
    @winrt_mixinmethod
    def put_RasterizePixelHeight(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource, win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_OpenFailed(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSource, win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceFailedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_OpenFailed(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetSourceAsync(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSource, streamSource: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceLoadStatus]: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RasterizePixelWidthProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RasterizePixelHeightProperty(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    RasterizePixelHeight = property(get_RasterizePixelHeight, put_RasterizePixelHeight)
    RasterizePixelWidth = property(get_RasterizePixelWidth, put_RasterizePixelWidth)
    UriSource = property(get_UriSource, put_UriSource)
    _SvgImageSource_Meta_.RasterizePixelHeightProperty = property(get_RasterizePixelHeightProperty, None)
    _SvgImageSource_Meta_.RasterizePixelWidthProperty = property(get_RasterizePixelWidthProperty, None)
    _SvgImageSource_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
    OpenFailed = event(add_OpenFailed, remove_OpenFailed)
    Opened = event(add_Opened, remove_Opened)
class SvgImageSourceFailedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFailedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceFailedEventArgs'
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceFailedEventArgs) -> win32more.Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceLoadStatus: ...
    Status = property(get_Status, None)
class SvgImageSourceLoadStatus(Enum, Int32):
    _name_ = 'Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceLoadStatus'
    Success = 0
    NetworkError = 1
    InvalidFormat = 2
    Other = 3
class SvgImageSourceOpenedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.ISvgImageSourceOpenedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.SvgImageSourceOpenedEventArgs'
class VirtualSurfaceImageSource(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Media.Imaging.SurfaceImageSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IVirtualSurfaceImageSource
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource.CreateInstanceWithDimensions(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource.CreateInstanceWithDimensionsAndOpacity(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithDimensions(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IVirtualSurfaceImageSourceFactory, pixelWidth: Int32, pixelHeight: Int32) -> win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource: ...
    @winrt_factorymethod
    def CreateInstanceWithDimensionsAndOpacity(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IVirtualSurfaceImageSourceFactory, pixelWidth: Int32, pixelHeight: Int32, isOpaque: Boolean) -> win32more.Microsoft.UI.Xaml.Media.Imaging.VirtualSurfaceImageSource: ...
class WriteableBitmap(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Media.Imaging.BitmapSource
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmap
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.WriteableBitmap'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.WriteableBitmap.CreateInstanceWithDimensions(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithDimensions(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmapFactory, pixelWidth: Int32, pixelHeight: Int32) -> win32more.Microsoft.UI.Xaml.Media.Imaging.WriteableBitmap: ...
    @winrt_mixinmethod
    def get_PixelBuffer(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmap) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def Invalidate(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IWriteableBitmap) -> Void: ...
    PixelBuffer = property(get_PixelBuffer, None)
class XamlRenderingBackgroundTask(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTask
    _classid_ = 'Microsoft.UI.Xaml.Media.Imaging.XamlRenderingBackgroundTask'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Media.Imaging.XamlRenderingBackgroundTask.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTaskFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Media.Imaging.XamlRenderingBackgroundTask: ...
    @winrt_mixinmethod
    def OnRun(self: win32more.Microsoft.UI.Xaml.Media.Imaging.IXamlRenderingBackgroundTaskOverrides, taskInstance: win32more.Windows.ApplicationModel.Background.IBackgroundTaskInstance) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.AppLifecycle
import win32more.Windows.ApplicationModel.Core
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class ActivationRegistrationManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.ActivationRegistrationManager'
    @winrt_classmethod
    def RegisterForFileTypeActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, supportedFileTypes: PassArray[hstr], logo: hstr, displayName: hstr, supportedVerbs: PassArray[hstr], exePath: hstr) -> Void: ...
    @winrt_classmethod
    def RegisterForProtocolActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, scheme: hstr, logo: hstr, displayName: hstr, exePath: hstr) -> Void: ...
    @winrt_classmethod
    def RegisterForStartupActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, taskId: hstr, exePath: hstr) -> Void: ...
    @winrt_classmethod
    def UnregisterForFileTypeActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, fileTypes: PassArray[hstr], exePath: hstr) -> Void: ...
    @winrt_classmethod
    def UnregisterForProtocolActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, scheme: hstr, exePath: hstr) -> Void: ...
    @winrt_classmethod
    def UnregisterForStartupActivation(cls: win32more.Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics, taskId: hstr) -> Void: ...
class AppActivationArguments(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppLifecycle.IAppActivationArguments
    _classid_ = 'Microsoft.Windows.AppLifecycle.AppActivationArguments'
    @winrt_mixinmethod
    def get_Kind(self: win32more.Microsoft.Windows.AppLifecycle.IAppActivationArguments) -> win32more.Microsoft.Windows.AppLifecycle.ExtendedActivationKind: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.Windows.AppLifecycle.IAppActivationArguments) -> IInspectable: ...
    Data = property(get_Data, None)
    Kind = property(get_Kind, None)
class AppInstance(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppLifecycle.IAppInstance
    _classid_ = 'Microsoft.Windows.AppLifecycle.AppInstance'
    @winrt_mixinmethod
    def UnregisterKey(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance) -> Void: ...
    @winrt_mixinmethod
    def RedirectActivationToAsync(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance, args: win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetActivatedEventArgs(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance) -> win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments: ...
    @winrt_mixinmethod
    def add_Activated(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Activated(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Key(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance) -> hstr: ...
    @winrt_mixinmethod
    def get_IsCurrent(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance) -> Boolean: ...
    @winrt_mixinmethod
    def get_ProcessId(self: win32more.Microsoft.Windows.AppLifecycle.IAppInstance) -> UInt32: ...
    @winrt_classmethod
    def Restart(cls: win32more.Microsoft.Windows.AppLifecycle.IAppInstanceStatics2, arguments: hstr) -> win32more.Windows.ApplicationModel.Core.AppRestartFailureReason: ...
    @winrt_classmethod
    def GetCurrent(cls: win32more.Microsoft.Windows.AppLifecycle.IAppInstanceStatics) -> win32more.Microsoft.Windows.AppLifecycle.AppInstance: ...
    @winrt_classmethod
    def GetInstances(cls: win32more.Microsoft.Windows.AppLifecycle.IAppInstanceStatics) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AppLifecycle.AppInstance]: ...
    @winrt_classmethod
    def FindOrRegisterForKey(cls: win32more.Microsoft.Windows.AppLifecycle.IAppInstanceStatics, key: hstr) -> win32more.Microsoft.Windows.AppLifecycle.AppInstance: ...
    IsCurrent = property(get_IsCurrent, None)
    Key = property(get_Key, None)
    ProcessId = property(get_ProcessId, None)
    Activated = event(add_Activated, remove_Activated)
AppLifecycleContract: UInt32 = 131072
class ExtendedActivationKind(Enum, Int32):
    _name_ = 'Microsoft.Windows.AppLifecycle.ExtendedActivationKind'
    Launch = 0
    Search = 1
    ShareTarget = 2
    File = 3
    Protocol = 4
    FileOpenPicker = 5
    FileSavePicker = 6
    CachedFileUpdater = 7
    ContactPicker = 8
    Device = 9
    PrintTaskSettings = 10
    CameraSettings = 11
    RestrictedLaunch = 12
    AppointmentsProvider = 13
    Contact = 14
    LockScreenCall = 15
    VoiceCommand = 16
    LockScreen = 17
    PickerReturned = 1000
    WalletAction = 1001
    PickFileContinuation = 1002
    PickSaveFileContinuation = 1003
    PickFolderContinuation = 1004
    WebAuthenticationBrokerContinuation = 1005
    WebAccountProvider = 1006
    ComponentUI = 1007
    ProtocolForResults = 1009
    ToastNotification = 1010
    Print3DWorkflow = 1011
    DialReceiver = 1012
    DevicePairing = 1013
    UserDataAccountsProvider = 1014
    FilePickerExperience = 1015
    LockScreenComponent = 1016
    ContactPanel = 1017
    PrintWorkflowForegroundTask = 1018
    GameUIProvider = 1019
    StartupTask = 1020
    CommandLineLaunch = 1021
    BarcodeScannerProvider = 1022
    PrintSupportJobUI = 1023
    PrintSupportSettingsUI = 1024
    PhoneCallActivation = 1025
    VpnForeground = 1026
    Push = 5000
    AppNotification = 5001
class IActivationRegistrationManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.IActivationRegistrationManagerStatics'
    _iid_ = Guid('{5ac4e92e-017b-5d68-8198-f68636ab99d3}')
    @winrt_commethod(6)
    def RegisterForFileTypeActivation(self, supportedFileTypes: PassArray[hstr], logo: hstr, displayName: hstr, supportedVerbs: PassArray[hstr], exePath: hstr) -> Void: ...
    @winrt_commethod(7)
    def RegisterForProtocolActivation(self, scheme: hstr, logo: hstr, displayName: hstr, exePath: hstr) -> Void: ...
    @winrt_commethod(8)
    def RegisterForStartupActivation(self, taskId: hstr, exePath: hstr) -> Void: ...
    @winrt_commethod(9)
    def UnregisterForFileTypeActivation(self, fileTypes: PassArray[hstr], exePath: hstr) -> Void: ...
    @winrt_commethod(10)
    def UnregisterForProtocolActivation(self, scheme: hstr, exePath: hstr) -> Void: ...
    @winrt_commethod(11)
    def UnregisterForStartupActivation(self, taskId: hstr) -> Void: ...
class IAppActivationArguments(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.IAppActivationArguments'
    _iid_ = Guid('{14f99eaf-1580-5062-bdc8-d5d1c31138fb}')
    @winrt_commethod(6)
    def get_Kind(self) -> win32more.Microsoft.Windows.AppLifecycle.ExtendedActivationKind: ...
    @winrt_commethod(7)
    def get_Data(self) -> IInspectable: ...
    Data = property(get_Data, None)
    Kind = property(get_Kind, None)
class IAppInstance(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.IAppInstance'
    _iid_ = Guid('{75766ae4-0239-5a26-b9da-d5bfc75a4866}')
    @winrt_commethod(6)
    def UnregisterKey(self) -> Void: ...
    @winrt_commethod(7)
    def RedirectActivationToAsync(self, args: win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def GetActivatedEventArgs(self) -> win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments: ...
    @winrt_commethod(9)
    def add_Activated(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.Windows.AppLifecycle.AppActivationArguments]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_Activated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def get_Key(self) -> hstr: ...
    @winrt_commethod(12)
    def get_IsCurrent(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_ProcessId(self) -> UInt32: ...
    IsCurrent = property(get_IsCurrent, None)
    Key = property(get_Key, None)
    ProcessId = property(get_ProcessId, None)
    Activated = event(add_Activated, remove_Activated)
class IAppInstanceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.IAppInstanceStatics'
    _iid_ = Guid('{4f414b25-8330-5a9b-bbc1-8229d479649d}')
    @winrt_commethod(6)
    def GetCurrent(self) -> win32more.Microsoft.Windows.AppLifecycle.AppInstance: ...
    @winrt_commethod(7)
    def GetInstances(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.Windows.AppLifecycle.AppInstance]: ...
    @winrt_commethod(8)
    def FindOrRegisterForKey(self, key: hstr) -> win32more.Microsoft.Windows.AppLifecycle.AppInstance: ...
class IAppInstanceStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppLifecycle.IAppInstanceStatics2'
    _iid_ = Guid('{fe9f1885-7160-5397-ba9b-5890b24fdc04}')
    @winrt_commethod(6)
    def Restart(self, arguments: hstr) -> win32more.Windows.ApplicationModel.Core.AppRestartFailureReason: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Automation
import win32more.Microsoft.UI.Xaml.Automation.Peers
import win32more.Microsoft.UI.Xaml.Automation.Provider
import win32more.Microsoft.UI.Xaml.Automation.Text
import win32more.Windows.Foundation
import win32more.Windows.UI
class IAnnotationProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IAnnotationProvider'
    _iid_ = Guid('{546ab18e-986d-5deb-8f2a-2d9303a43006}')
    @winrt_commethod(6)
    def get_AnnotationTypeId(self) -> Int32: ...
    @winrt_commethod(7)
    def get_AnnotationTypeName(self) -> hstr: ...
    @winrt_commethod(8)
    def get_Author(self) -> hstr: ...
    @winrt_commethod(9)
    def get_DateTime(self) -> hstr: ...
    @winrt_commethod(10)
    def get_Target(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    AnnotationTypeId = property(get_AnnotationTypeId, None)
    AnnotationTypeName = property(get_AnnotationTypeName, None)
    Author = property(get_Author, None)
    DateTime = property(get_DateTime, None)
    Target = property(get_Target, None)
class ICustomNavigationProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ICustomNavigationProvider'
    _iid_ = Guid('{cad51322-faa9-5a2b-90f0-b762c46178b3}')
    @winrt_commethod(6)
    def NavigateCustom(self, direction: win32more.Microsoft.UI.Xaml.Automation.Peers.AutomationNavigationDirection) -> IInspectable: ...
class IDockProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDockProvider'
    _iid_ = Guid('{9882b971-70ea-5c6d-a818-7a7ab68c6f3b}')
    @winrt_commethod(6)
    def get_DockPosition(self) -> win32more.Microsoft.UI.Xaml.Automation.DockPosition: ...
    @winrt_commethod(7)
    def SetDockPosition(self, dockPosition: win32more.Microsoft.UI.Xaml.Automation.DockPosition) -> Void: ...
    DockPosition = property(get_DockPosition, None)
class IDragProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDragProvider'
    _iid_ = Guid('{c60bb643-a356-5132-a258-ffba6c7480f2}')
    @winrt_commethod(6)
    def get_IsGrabbed(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DropEffect(self) -> hstr: ...
    @winrt_commethod(8)
    def get_DropEffects(self) -> ReceiveArray[hstr]: ...
    @winrt_commethod(9)
    def GetGrabbedItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    DropEffect = property(get_DropEffect, None)
    DropEffects = property(get_DropEffects, None)
    IsGrabbed = property(get_IsGrabbed, None)
class IDropTargetProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IDropTargetProvider'
    _iid_ = Guid('{9b2a9f3d-bbb1-510d-99e8-0e0ae14a6e3b}')
    @winrt_commethod(6)
    def get_DropEffect(self) -> hstr: ...
    @winrt_commethod(7)
    def get_DropEffects(self) -> ReceiveArray[hstr]: ...
    DropEffect = property(get_DropEffect, None)
    DropEffects = property(get_DropEffects, None)
class IExpandCollapseProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IExpandCollapseProvider'
    _iid_ = Guid('{6cef349c-b181-5d0b-b297-c3b0166120c3}')
    @winrt_commethod(6)
    def get_ExpandCollapseState(self) -> win32more.Microsoft.UI.Xaml.Automation.ExpandCollapseState: ...
    @winrt_commethod(7)
    def Collapse(self) -> Void: ...
    @winrt_commethod(8)
    def Expand(self) -> Void: ...
    ExpandCollapseState = property(get_ExpandCollapseState, None)
class IGridItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IGridItemProvider'
    _iid_ = Guid('{d2557a0e-6909-5170-a680-60728df339b4}')
    @winrt_commethod(6)
    def get_Column(self) -> Int32: ...
    @winrt_commethod(7)
    def get_ColumnSpan(self) -> Int32: ...
    @winrt_commethod(8)
    def get_ContainingGrid(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(9)
    def get_Row(self) -> Int32: ...
    @winrt_commethod(10)
    def get_RowSpan(self) -> Int32: ...
    Column = property(get_Column, None)
    ColumnSpan = property(get_ColumnSpan, None)
    ContainingGrid = property(get_ContainingGrid, None)
    Row = property(get_Row, None)
    RowSpan = property(get_RowSpan, None)
class IGridProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IGridProvider'
    _iid_ = Guid('{50992d5e-d225-56e9-a25a-78c372e81955}')
    @winrt_commethod(6)
    def get_ColumnCount(self) -> Int32: ...
    @winrt_commethod(7)
    def get_RowCount(self) -> Int32: ...
    @winrt_commethod(8)
    def GetItem(self, row: Int32, column: Int32) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    ColumnCount = property(get_ColumnCount, None)
    RowCount = property(get_RowCount, None)
class IIRawElementProviderSimple(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IIRawElementProviderSimple'
    _iid_ = Guid('{f90bc239-ade2-55c9-a838-a3b0579763c5}')
class IInvokeProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IInvokeProvider'
    _iid_ = Guid('{02481105-3378-544d-b4e1-a1b368afbc02}')
    @winrt_commethod(6)
    def Invoke(self) -> Void: ...
class IItemContainerProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IItemContainerProvider'
    _iid_ = Guid('{ad297363-694e-5885-997d-a2d6dff415a7}')
    @winrt_commethod(6)
    def FindItemByProperty(self, startAfter: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple, automationProperty: win32more.Microsoft.UI.Xaml.Automation.AutomationProperty, value: IInspectable) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
class IMultipleViewProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IMultipleViewProvider'
    _iid_ = Guid('{60be5484-3d8f-51fd-beab-423422ee1e03}')
    @winrt_commethod(6)
    def get_CurrentView(self) -> Int32: ...
    @winrt_commethod(7)
    def GetSupportedViews(self) -> ReceiveArray[Int32]: ...
    @winrt_commethod(8)
    def GetViewName(self, viewId: Int32) -> hstr: ...
    @winrt_commethod(9)
    def SetCurrentView(self, viewId: Int32) -> Void: ...
    CurrentView = property(get_CurrentView, None)
class IObjectModelProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IObjectModelProvider'
    _iid_ = Guid('{92953ed0-4bd8-5624-8e3d-78d45fde9cf2}')
    @winrt_commethod(6)
    def GetUnderlyingObjectModel(self) -> IInspectable: ...
class IRangeValueProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IRangeValueProvider'
    _iid_ = Guid('{729ae414-1e8f-5020-82bb-bb574d145fd8}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_LargeChange(self) -> Double: ...
    @winrt_commethod(8)
    def get_Maximum(self) -> Double: ...
    @winrt_commethod(9)
    def get_Minimum(self) -> Double: ...
    @winrt_commethod(10)
    def get_SmallChange(self) -> Double: ...
    @winrt_commethod(11)
    def get_Value(self) -> Double: ...
    @winrt_commethod(12)
    def SetValue(self, value: Double) -> Void: ...
    IsReadOnly = property(get_IsReadOnly, None)
    LargeChange = property(get_LargeChange, None)
    Maximum = property(get_Maximum, None)
    Minimum = property(get_Minimum, None)
    SmallChange = property(get_SmallChange, None)
    Value = property(get_Value, None)
class IRawElementProviderSimple(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Automation.Provider.IIRawElementProviderSimple
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple'
class IScrollItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IScrollItemProvider'
    _iid_ = Guid('{8a6fb8eb-e5f1-58eb-8e72-8b95f236fc47}')
    @winrt_commethod(6)
    def ScrollIntoView(self) -> Void: ...
class IScrollProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IScrollProvider'
    _iid_ = Guid('{7e2e5af3-ff50-5365-bcfe-ef424b2fd590}')
    @winrt_commethod(6)
    def get_HorizontallyScrollable(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HorizontalScrollPercent(self) -> Double: ...
    @winrt_commethod(8)
    def get_HorizontalViewSize(self) -> Double: ...
    @winrt_commethod(9)
    def get_VerticallyScrollable(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_VerticalScrollPercent(self) -> Double: ...
    @winrt_commethod(11)
    def get_VerticalViewSize(self) -> Double: ...
    @winrt_commethod(12)
    def Scroll(self, horizontalAmount: win32more.Microsoft.UI.Xaml.Automation.ScrollAmount, verticalAmount: win32more.Microsoft.UI.Xaml.Automation.ScrollAmount) -> Void: ...
    @winrt_commethod(13)
    def SetScrollPercent(self, horizontalPercent: Double, verticalPercent: Double) -> Void: ...
    HorizontalScrollPercent = property(get_HorizontalScrollPercent, None)
    HorizontalViewSize = property(get_HorizontalViewSize, None)
    HorizontallyScrollable = property(get_HorizontallyScrollable, None)
    VerticalScrollPercent = property(get_VerticalScrollPercent, None)
    VerticalViewSize = property(get_VerticalViewSize, None)
    VerticallyScrollable = property(get_VerticallyScrollable, None)
class ISelectionItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISelectionItemProvider'
    _iid_ = Guid('{c9dfdd81-d4ac-5d31-be7f-24fab16060e4}')
    @winrt_commethod(6)
    def get_IsSelected(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_SelectionContainer(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(8)
    def AddToSelection(self) -> Void: ...
    @winrt_commethod(9)
    def RemoveFromSelection(self) -> Void: ...
    @winrt_commethod(10)
    def Select(self) -> Void: ...
    IsSelected = property(get_IsSelected, None)
    SelectionContainer = property(get_SelectionContainer, None)
class ISelectionProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISelectionProvider'
    _iid_ = Guid('{80d56d4e-0052-541f-9411-9d1778b3bfca}')
    @winrt_commethod(6)
    def get_CanSelectMultiple(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsSelectionRequired(self) -> Boolean: ...
    @winrt_commethod(8)
    def GetSelection(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    CanSelectMultiple = property(get_CanSelectMultiple, None)
    IsSelectionRequired = property(get_IsSelectionRequired, None)
class ISpreadsheetItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISpreadsheetItemProvider'
    _iid_ = Guid('{51c1ce89-b21f-592c-8768-0accdefd5738}')
    @winrt_commethod(6)
    def get_Formula(self) -> hstr: ...
    @winrt_commethod(7)
    def GetAnnotationObjects(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(8)
    def GetAnnotationTypes(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.AnnotationType]: ...
    Formula = property(get_Formula, None)
class ISpreadsheetProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISpreadsheetProvider'
    _iid_ = Guid('{1ff41bac-d9e3-5e48-b5f8-9eab0fb2d9d8}')
    @winrt_commethod(6)
    def GetItemByName(self, name: hstr) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
class IStylesProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IStylesProvider'
    _iid_ = Guid('{d8895839-0048-54de-9c1f-152de6665e80}')
    @winrt_commethod(6)
    def get_ExtendedProperties(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FillColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(8)
    def get_FillPatternColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def get_FillPatternStyle(self) -> hstr: ...
    @winrt_commethod(10)
    def get_Shape(self) -> hstr: ...
    @winrt_commethod(11)
    def get_StyleId(self) -> Int32: ...
    @winrt_commethod(12)
    def get_StyleName(self) -> hstr: ...
    ExtendedProperties = property(get_ExtendedProperties, None)
    FillColor = property(get_FillColor, None)
    FillPatternColor = property(get_FillPatternColor, None)
    FillPatternStyle = property(get_FillPatternStyle, None)
    Shape = property(get_Shape, None)
    StyleId = property(get_StyleId, None)
    StyleName = property(get_StyleName, None)
class ISynchronizedInputProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ISynchronizedInputProvider'
    _iid_ = Guid('{c5615613-936d-5289-a190-e82057e0ff5a}')
    @winrt_commethod(6)
    def Cancel(self) -> Void: ...
    @winrt_commethod(7)
    def StartListening(self, inputType: win32more.Microsoft.UI.Xaml.Automation.SynchronizedInputType) -> Void: ...
class ITableItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITableItemProvider'
    _iid_ = Guid('{6ce6f038-54d4-5553-a4ad-03cbcf358197}')
    @winrt_commethod(6)
    def GetColumnHeaderItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(7)
    def GetRowHeaderItems(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
class ITableProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITableProvider'
    _iid_ = Guid('{9aba6724-b22d-5db8-8abb-81f911f18af2}')
    @winrt_commethod(6)
    def get_RowOrColumnMajor(self) -> win32more.Microsoft.UI.Xaml.Automation.RowOrColumnMajor: ...
    @winrt_commethod(7)
    def GetColumnHeaders(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    @winrt_commethod(8)
    def GetRowHeaders(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
    RowOrColumnMajor = property(get_RowOrColumnMajor, None)
class ITextChildProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextChildProvider'
    _iid_ = Guid('{7c72e55f-f75d-5522-aeb5-c1f82c32933b}')
    @winrt_commethod(6)
    def get_TextContainer(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(7)
    def get_TextRange(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    TextContainer = property(get_TextContainer, None)
    TextRange = property(get_TextRange, None)
class ITextEditProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextEditProvider'
    _iid_ = Guid('{7f09bbe8-bea7-5dd3-ba6b-28dbb402fad4}')
    @winrt_commethod(6)
    def GetActiveComposition(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def GetConversionTarget(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
class ITextProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextProvider'
    _iid_ = Guid('{37e7dce6-fe7a-56a7-a47a-9462872c67ef}')
    @winrt_commethod(6)
    def get_DocumentRange(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def get_SupportedTextSelection(self) -> win32more.Microsoft.UI.Xaml.Automation.SupportedTextSelection: ...
    @winrt_commethod(8)
    def GetSelection(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider]: ...
    @winrt_commethod(9)
    def GetVisibleRanges(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider]: ...
    @winrt_commethod(10)
    def RangeFromChild(self, childElement: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(11)
    def RangeFromPoint(self, screenLocation: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    DocumentRange = property(get_DocumentRange, None)
    SupportedTextSelection = property(get_SupportedTextSelection, None)
class ITextProvider2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextProvider2'
    _iid_ = Guid('{6844f012-c7e6-5763-ba04-5b6db910cd34}')
    @winrt_commethod(6)
    def RangeFromAnnotation(self, annotationElement: win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def GetCaretRange(self, isActive: POINTER(Boolean)) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
class ITextRangeProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider'
    _iid_ = Guid('{84210361-6ce2-5084-bf3b-28afa6e9851f}')
    @winrt_commethod(6)
    def Clone(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(7)
    def Compare(self, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider) -> Boolean: ...
    @winrt_commethod(8)
    def CompareEndpoints(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider, targetEndpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint) -> Int32: ...
    @winrt_commethod(9)
    def ExpandToEnclosingUnit(self, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit) -> Void: ...
    @winrt_commethod(10)
    def FindAttribute(self, attributeId: Int32, value: IInspectable, backward: Boolean) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(11)
    def FindText(self, text: hstr, backward: Boolean, ignoreCase: Boolean) -> win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider: ...
    @winrt_commethod(12)
    def GetAttributeValue(self, attributeId: Int32) -> IInspectable: ...
    @winrt_commethod(13)
    def GetBoundingRectangles(self, returnValue: ReceiveArray[Double]) -> Void: ...
    @winrt_commethod(14)
    def GetEnclosingElement(self) -> win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple: ...
    @winrt_commethod(15)
    def GetText(self, maxLength: Int32) -> hstr: ...
    @winrt_commethod(16)
    def Move(self, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit, count: Int32) -> Int32: ...
    @winrt_commethod(17)
    def MoveEndpointByUnit(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, unit: win32more.Microsoft.UI.Xaml.Automation.Text.TextUnit, count: Int32) -> Int32: ...
    @winrt_commethod(18)
    def MoveEndpointByRange(self, endpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint, textRangeProvider: win32more.Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider, targetEndpoint: win32more.Microsoft.UI.Xaml.Automation.Text.TextPatternRangeEndpoint) -> Void: ...
    @winrt_commethod(19)
    def Select(self) -> Void: ...
    @winrt_commethod(20)
    def AddToSelection(self) -> Void: ...
    @winrt_commethod(21)
    def RemoveFromSelection(self) -> Void: ...
    @winrt_commethod(22)
    def ScrollIntoView(self, alignToTop: Boolean) -> Void: ...
    @winrt_commethod(23)
    def GetChildren(self) -> ReceiveArray[win32more.Microsoft.UI.Xaml.Automation.Provider.IRawElementProviderSimple]: ...
class ITextRangeProvider2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITextRangeProvider2'
    _iid_ = Guid('{34d4a80e-36bb-5362-a53b-490428a8b367}')
    @winrt_commethod(6)
    def ShowContextMenu(self) -> Void: ...
class IToggleProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IToggleProvider'
    _iid_ = Guid('{021080c2-30a9-52ef-bc32-2b79847b6ba7}')
    @winrt_commethod(6)
    def get_ToggleState(self) -> win32more.Microsoft.UI.Xaml.Automation.ToggleState: ...
    @winrt_commethod(7)
    def Toggle(self) -> Void: ...
    ToggleState = property(get_ToggleState, None)
class ITransformProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITransformProvider'
    _iid_ = Guid('{6fd76988-8f52-5ef2-a826-9c8c4951c911}')
    @winrt_commethod(6)
    def get_CanMove(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_CanResize(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_CanRotate(self) -> Boolean: ...
    @winrt_commethod(9)
    def Move(self, x: Double, y: Double) -> Void: ...
    @winrt_commethod(10)
    def Resize(self, width: Double, height: Double) -> Void: ...
    @winrt_commethod(11)
    def Rotate(self, degrees: Double) -> Void: ...
    CanMove = property(get_CanMove, None)
    CanResize = property(get_CanResize, None)
    CanRotate = property(get_CanRotate, None)
class ITransformProvider2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.ITransformProvider2'
    _iid_ = Guid('{7d91d02d-8401-5cf8-bbc4-47391a524215}')
    @winrt_commethod(6)
    def get_CanZoom(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_ZoomLevel(self) -> Double: ...
    @winrt_commethod(8)
    def get_MaxZoom(self) -> Double: ...
    @winrt_commethod(9)
    def get_MinZoom(self) -> Double: ...
    @winrt_commethod(10)
    def Zoom(self, zoom: Double) -> Void: ...
    @winrt_commethod(11)
    def ZoomByUnit(self, zoomUnit: win32more.Microsoft.UI.Xaml.Automation.ZoomUnit) -> Void: ...
    CanZoom = property(get_CanZoom, None)
    MaxZoom = property(get_MaxZoom, None)
    MinZoom = property(get_MinZoom, None)
    ZoomLevel = property(get_ZoomLevel, None)
class IValueProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IValueProvider'
    _iid_ = Guid('{984f11cf-4611-588e-b52e-b96a12322c71}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Value(self) -> hstr: ...
    @winrt_commethod(8)
    def SetValue(self, value: hstr) -> Void: ...
    IsReadOnly = property(get_IsReadOnly, None)
    Value = property(get_Value, None)
class IVirtualizedItemProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IVirtualizedItemProvider'
    _iid_ = Guid('{098f858a-2e63-5985-ab87-f8ebdb1c5740}')
    @winrt_commethod(6)
    def Realize(self) -> Void: ...
class IWindowProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Automation.Provider.IWindowProvider'
    _iid_ = Guid('{83f1df99-9ddf-575e-a651-2ee657fd16e0}')
    @winrt_commethod(6)
    def get_IsModal(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsTopmost(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_Maximizable(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_Minimizable(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_InteractionState(self) -> win32more.Microsoft.UI.Xaml.Automation.WindowInteractionState: ...
    @winrt_commethod(11)
    def get_VisualState(self) -> win32more.Microsoft.UI.Xaml.Automation.WindowVisualState: ...
    @winrt_commethod(12)
    def Close(self) -> Void: ...
    @winrt_commethod(13)
    def SetVisualState(self, state: win32more.Microsoft.UI.Xaml.Automation.WindowVisualState) -> Void: ...
    @winrt_commethod(14)
    def WaitForInputIdle(self, milliseconds: Int32) -> Boolean: ...
    InteractionState = property(get_InteractionState, None)
    IsModal = property(get_IsModal, None)
    IsTopmost = property(get_IsTopmost, None)
    Maximizable = property(get_Maximizable, None)
    Minimizable = property(get_Minimizable, None)
    VisualState = property(get_VisualState, None)


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Composition.Effects
import win32more.Windows.Graphics.Effects
class ISceneLightingEffect(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Composition.Effects.ISceneLightingEffect'
    _iid_ = Guid('{eb1e7316-114c-5950-8480-20a29a3bb1ee}')
    @winrt_commethod(6)
    def get_AmbientAmount(self) -> Single: ...
    @winrt_commethod(7)
    def put_AmbientAmount(self, value: Single) -> Void: ...
    @winrt_commethod(8)
    def get_DiffuseAmount(self) -> Single: ...
    @winrt_commethod(9)
    def put_DiffuseAmount(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def get_NormalMapSource(self) -> win32more.Windows.Graphics.Effects.IGraphicsEffectSource: ...
    @winrt_commethod(11)
    def put_NormalMapSource(self, value: win32more.Windows.Graphics.Effects.IGraphicsEffectSource) -> Void: ...
    @winrt_commethod(12)
    def get_SpecularAmount(self) -> Single: ...
    @winrt_commethod(13)
    def put_SpecularAmount(self, value: Single) -> Void: ...
    @winrt_commethod(14)
    def get_SpecularShine(self) -> Single: ...
    @winrt_commethod(15)
    def put_SpecularShine(self, value: Single) -> Void: ...
    AmbientAmount = property(get_AmbientAmount, put_AmbientAmount)
    DiffuseAmount = property(get_DiffuseAmount, put_DiffuseAmount)
    NormalMapSource = property(get_NormalMapSource, put_NormalMapSource)
    SpecularAmount = property(get_SpecularAmount, put_SpecularAmount)
    SpecularShine = property(get_SpecularShine, put_SpecularShine)
class ISceneLightingEffect2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Composition.Effects.ISceneLightingEffect2'
    _iid_ = Guid('{6b6496b2-468d-50d1-bbe9-593b8263ad80}')
    @winrt_commethod(6)
    def get_ReflectanceModel(self) -> win32more.Microsoft.UI.Composition.Effects.SceneLightingEffectReflectanceModel: ...
    @winrt_commethod(7)
    def put_ReflectanceModel(self, value: win32more.Microsoft.UI.Composition.Effects.SceneLightingEffectReflectanceModel) -> Void: ...
    ReflectanceModel = property(get_ReflectanceModel, put_ReflectanceModel)
class SceneLightingEffect(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect
    _classid_ = 'Microsoft.UI.Composition.Effects.SceneLightingEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Composition.Effects.SceneLightingEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Composition.Effects.SceneLightingEffect: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Windows.Graphics.Effects.IGraphicsEffect, name: hstr) -> Void: ...
    @winrt_mixinmethod
    def put_SpecularAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_SpecularShine(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect) -> Single: ...
    @winrt_mixinmethod
    def put_SpecularShine(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_ReflectanceModel(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect2) -> win32more.Microsoft.UI.Composition.Effects.SceneLightingEffectReflectanceModel: ...
    @winrt_mixinmethod
    def put_ReflectanceModel(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect2, value: win32more.Microsoft.UI.Composition.Effects.SceneLightingEffectReflectanceModel) -> Void: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Effects.IGraphicsEffect) -> hstr: ...
    @winrt_mixinmethod
    def get_AmbientAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect) -> Single: ...
    @winrt_mixinmethod
    def put_AmbientAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_DiffuseAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect) -> Single: ...
    @winrt_mixinmethod
    def put_DiffuseAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_NormalMapSource(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect) -> win32more.Windows.Graphics.Effects.IGraphicsEffectSource: ...
    @winrt_mixinmethod
    def put_NormalMapSource(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect, value: win32more.Windows.Graphics.Effects.IGraphicsEffectSource) -> Void: ...
    @winrt_mixinmethod
    def get_SpecularAmount(self: win32more.Microsoft.UI.Composition.Effects.ISceneLightingEffect) -> Single: ...
    AmbientAmount = property(get_AmbientAmount, put_AmbientAmount)
    DiffuseAmount = property(get_DiffuseAmount, put_DiffuseAmount)
    Name = property(get_Name, put_Name)
    NormalMapSource = property(get_NormalMapSource, put_NormalMapSource)
    ReflectanceModel = property(get_ReflectanceModel, put_ReflectanceModel)
    SpecularAmount = property(get_SpecularAmount, put_SpecularAmount)
    SpecularShine = property(get_SpecularShine, put_SpecularShine)
class SceneLightingEffectReflectanceModel(Enum, Int32):
    _name_ = 'Microsoft.UI.Composition.Effects.SceneLightingEffectReflectanceModel'
    BlinnPhong = 0
    PhysicallyBasedBlinnPhong = 1


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.PushNotifications
import win32more.Windows.ApplicationModel.Background
import win32more.Windows.Foundation
class IPushNotificationChannel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationChannel'
    _iid_ = Guid('{da28bbcb-7695-5d38-af82-f30b72fef1f6}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_ExpirationTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(8)
    def Close(self) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
class IPushNotificationCreateChannelResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult'
    _iid_ = Guid('{4df3717f-5d33-56e9-b381-1b350c95722e}')
    @winrt_commethod(6)
    def get_Channel(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannel: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_Status(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus: ...
    Channel = property(get_Channel, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class IPushNotificationManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationManager'
    _iid_ = Guid('{902f4aba-ff63-5dfe-a88f-15cc6bed55ff}')
    @winrt_commethod(6)
    def Register(self) -> Void: ...
    @winrt_commethod(7)
    def Unregister(self) -> Void: ...
    @winrt_commethod(8)
    def UnregisterAll(self) -> Void: ...
    @winrt_commethod(9)
    def CreateChannelAsync(self, remoteId: Guid) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult, win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelStatus]: ...
    @winrt_commethod(10)
    def add_PushReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.PushNotifications.PushNotificationManager, win32more.Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_PushReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PushReceived = event(add_PushReceived, remove_PushReceived)
class IPushNotificationManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics'
    _iid_ = Guid('{71329470-1b55-58dc-a00c-68c26f2d8bd9}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Default(self) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationManager: ...
    Default = property(get_Default, None)
class IPushNotificationReceivedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs'
    _iid_ = Guid('{fbd4ec53-bb83-5495-8777-d3cf13e4299c}')
    @winrt_commethod(6)
    def get_Payload(self) -> ReceiveArray[Byte]: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskDeferral: ...
    @winrt_commethod(8)
    def add_Canceled(self, handler: win32more.Windows.ApplicationModel.Background.BackgroundTaskCanceledEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_Canceled(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Payload = property(get_Payload, None)
    Canceled = event(add_Canceled, remove_Canceled)
class PushNotificationChannel(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationChannel'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_ExpirationTime(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def Close(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationChannel) -> Void: ...
    ExpirationTime = property(get_ExpirationTime, None)
    Uri = property(get_Uri, None)
class PushNotificationChannelStatus(Enum, Int32):
    _name_ = 'Microsoft.Windows.PushNotifications.PushNotificationChannelStatus'
    InProgress = 0
    InProgressRetry = 1
    CompletedSuccess = 2
    CompletedFailure = 3
class PushNotificationCreateChannelResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult'
    @winrt_mixinmethod
    def get_Channel(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannel: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationCreateChannelResult) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus: ...
    Channel = property(get_Channel, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class PushNotificationCreateChannelStatus(Structure):
    _name_ = 'Microsoft.Windows.PushNotifications.PushNotificationCreateChannelStatus'
    status: win32more.Microsoft.Windows.PushNotifications.PushNotificationChannelStatus
    extendedError: win32more.Windows.Foundation.HResult
    retryCount: UInt32
class _PushNotificationManager_Meta_(ComPtr.__class__):
    pass
class PushNotificationManager(ComPtr, metaclass=_PushNotificationManager_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationManager'
    @winrt_mixinmethod
    def Register(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def Unregister(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def UnregisterAll(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager) -> Void: ...
    @winrt_mixinmethod
    def CreateChannelAsync(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, remoteId: Guid) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelResult, win32more.Microsoft.Windows.PushNotifications.PushNotificationCreateChannelStatus]: ...
    @winrt_mixinmethod
    def add_PushReceived(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.PushNotifications.PushNotificationManager, win32more.Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PushReceived(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics) -> Boolean: ...
    @winrt_classmethod
    def get_Default(cls: win32more.Microsoft.Windows.PushNotifications.IPushNotificationManagerStatics) -> win32more.Microsoft.Windows.PushNotifications.PushNotificationManager: ...
    _PushNotificationManager_Meta_.Default = property(get_Default, None)
    PushReceived = event(add_PushReceived, remove_PushReceived)
class PushNotificationReceivedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs
    _classid_ = 'Microsoft.Windows.PushNotifications.PushNotificationReceivedEventArgs'
    @winrt_mixinmethod
    def get_Payload(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskDeferral: ...
    @winrt_mixinmethod
    def add_Canceled(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs, handler: win32more.Windows.ApplicationModel.Background.BackgroundTaskCanceledEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Canceled(self: win32more.Microsoft.Windows.PushNotifications.IPushNotificationReceivedEventArgs, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Payload = property(get_Payload, None)
    Canceled = event(add_Canceled, remove_Canceled)
PushNotificationsContract: UInt32 = 65536


make_ready(__name__)
